==> jersey-cdi1x-2.34-sources.jar: org/glassfish/jersey/ext/cdi1x/internal/ProcessJAXRSAnnotatedTypes.java <==
/*
 * Copyright (c) 2018 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */
package org.glassfish.jersey.ext.cdi1x.internal;

import javax.enterprise.event.Observes;
import javax.enterprise.inject.spi.BeanManager;
import javax.enterprise.inject.spi.Extension;
import javax.enterprise.inject.spi.ProcessAnnotatedType;
import javax.enterprise.inject.spi.WithAnnotations;
import javax.ws.rs.ApplicationPath;
import javax.ws.rs.BeanParam;
import javax.ws.rs.FormParam;
import javax.ws.rs.HeaderParam;
import javax.ws.rs.MatrixParam;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;

public class ProcessJAXRSAnnotatedTypes implements Extension {

    public void processAnnotatedType(
            @Observes
            @WithAnnotations({
                  Context.class,
                  ApplicationPath.class,
                  HeaderParam.class,
                  QueryParam.class,
                  FormParam.class,
                  MatrixParam.class,
                  BeanParam.class,
                  PathParam.class})
            ProcessAnnotatedType<?> processAnnotatedType, BeanManager beanManager) {

        beanManager.getExtension(CdiComponentProvider.class)
                   .processAnnotatedType(processAnnotatedType);
    }

}

==> jersey-cdi1x-3.1.1-sources.jar: org/glassfish/jersey/ext/cdi1x/internal/ProcessJAXRSAnnotatedTypes.java <==
/*
 * Copyright (c) 2018 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */
package org.glassfish.jersey.ext.cdi1x.internal;

import jakarta.enterprise.event.Observes;
import jakarta.enterprise.inject.spi.BeanManager;
import jakarta.enterprise.inject.spi.Extension;
import jakarta.enterprise.inject.spi.ProcessAnnotatedType;
import jakarta.enterprise.inject.spi.WithAnnotations;
import jakarta.ws.rs.ApplicationPath;
import jakarta.ws.rs.BeanParam;
import jakarta.ws.rs.FormParam;
import jakarta.ws.rs.HeaderParam;
import jakarta.ws.rs.MatrixParam;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.QueryParam;
import jakarta.ws.rs.core.Context;

public class ProcessJAXRSAnnotatedTypes implements Extension {

    public void processAnnotatedType(
            @Observes
            @WithAnnotations({
                  Context.class,
                  ApplicationPath.class,
                  HeaderParam.class,
                  QueryParam.class,
                  FormParam.class,
                  MatrixParam.class,
                  BeanParam.class,
                  PathParam.class})
            ProcessAnnotatedType<?> processAnnotatedType, BeanManager beanManager) {

        beanManager.getExtension(CdiComponentProvider.class)
                   .processAnnotatedType(processAnnotatedType);
    }

}
